
# MyALGO

This is a simple and naive algotrade for CTA

We removed the useless part for personal traders, and changed its' test target to CTA trade.

To use this framework,you need a mysql database and history data for some kind of trade.

## requirements

- python 3.6 (LTS)
- mysql 5.6 (8.0 is not suggested)

## Features

- CTA Supported
- Mysql Supported
- simplified fill process and ignored fill-strategies(for personal traders,this is useless)
- enumerate states and actions
- getters and setters with @property and @property.setter
- PEP8 naming style.

## TODOs

- analyzer
- plot and visual

- online-trading
